@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from datetime import timedelta
+from time import timezone
 from github import Github
 from actor import actor
 from event import event
@@ -10,7 +12,7 @@ def get(user,email,count=10):
     i=0
     for e in g.get_user(user).get_events():
         a=e.actor
-        e=event(created_at=e.created_at,
+        e=event(created_at=e.created_at+timedelta(seconds=-timezone),
             actor=actor(login=a.login,
                 avatar_url=a.avatar_url,
                 url=a.url,
