@@ -51,11 +51,15 @@ class event:
                 (login,url.split("/")[-1],description)
             raise TypeError("GistEvent action %s not implemeted yet" % action)
         if self.type=="IssuesEvent":
-            print payload
             title=payload["issue"]["title"]
             url=payload["issue"]["url"]
             return "%s %s issue\n%s\n%s" % \
             (login,action,title,url)
+        if self.type=="IssueCommentEvent":
+            title=payload["issue"]["title"]
+            url=payload["issue"]["url"]
+            return "%s %s comment issue\n%s\n%s" % \
+            (login,action,title,url)
         if self.type=="PullRequestEvent":
             return "%s opened pull request %s\n%s" % \
             (login,repo.name,payload['pull_request']['title'])
